@@ -1,5 +1,5 @@
 /*
- *  $Id: breakdetector.c,v 1.3 2002/08/22 09:37:22 dreibh Exp $
+ *  $Id: breakdetector.c,v 1.3 2004/11/10 22:07:34 dreibh Exp $
  *
  * RSerPool implementation.
  *
@@ -11,14 +11,19 @@
  * Forschung (BMBF) of the Federal Republic of Germany (Frderkennzeichen 01AK045).
  * The authors alone are responsible for the contents.
  *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public
- * License as published by the Free Software Foundation; either
- * version 2.1 of the License, or (at your option) any later version.
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License
+ * as published by the Free Software Foundation; either version 2
+ * of the License, or (at your option) any later version.
  *
- * You should have received a copy of the GNU Lesser General Public
- * License along with this library; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
  *
  * There are two mailinglists available at http://www.sctp.de/rserpool.html
  * which should be used for any discussion related to this implementation.
@@ -33,8 +38,9 @@
 
 #include "tdtypes.h"
 #include "breakdetector.h"
-#include "utilities.h"
+#include "timeutilities.h"
 
+#include <sys/types.h>
 #include <signal.h>
 
 
