@@ -1,5 +1,5 @@
 /*
- *  $Id: randomizer.c,v 1.5 2002/08/22 09:37:25 dreibh Exp $
+ *  $Id: randomizer.c,v 1.10 2004/11/12 00:16:51 dreibh Exp $
  *
  * RSerPool implementation.
  *
@@ -11,14 +11,19 @@
  * Forschung (BMBF) of the Federal Republic of Germany (Frderkennzeichen 01AK045).
  * The authors alone are responsible for the contents.
  *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public
- * License as published by the Free Software Foundation; either
- * version 2.1 of the License, or (at your option) any later version.
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License
+ * as published by the Free Software Foundation; either version 2
+ * of the License, or (at your option) any later version.
  *
- * You should have received a copy of the GNU Lesser General Public
- * License along with this library; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
  *
  * There are two mailinglists available at http://www.sctp.de/rserpool.html
  * which should be used for any discussion related to this implementation.
@@ -30,12 +35,16 @@
  *
  */
 
-
-#include "tdtypes.h"
 #include "randomizer.h"
-#include "utilities.h"
+#include "timeutilities.h"
+
+#include <stdio.h>
+#include <stdlib.h>
 
 
+#ifdef NDEBUG
+#include <omnetpp.h>
+#else
 /*
    It is tried to use /dev/urandom as random source first, since
    it provides high-quality random numbers. If /dev/urandom is not
@@ -52,8 +61,9 @@
 
 
 
-int          RandomSource = RS_TRY_DEVICE;
+static int   RandomSource = RS_TRY_DEVICE;
 static FILE* RandomDevice = NULL;
+#endif
 
 
 
@@ -81,25 +91,26 @@ uint64_t random64()
 /* ###### Get 32-bit random value ######################################## */
 uint32_t random32()
 {
-   uint32_t number;
+#ifdef NDEBUG
+#warning Using OMNeT++ random generator
+   const double value = uniform(0.0, (double)0xffffffff);
+   return((uint32_t)rint(value));
+#else
+  uint32_t number;
 
    switch(RandomSource) {
       case RS_DEVICE:
-         if(fread(&number,sizeof(number),1,RandomDevice) == 1) {
+         if(fread(&number, sizeof(number), 1, RandomDevice) == 1) {
             return(number);
          }
          RandomSource = RS_CLIB;
-
-         LOG_WARNING
-         fputs("Unable to read from /dev/urandom - using clib's random() function!\n",stdlog);
-         LOG_END
       case RS_CLIB:
          return(random());
        break;
       case RS_TRY_DEVICE:
-         RandomDevice = fopen("/dev/urandom","r");
+         RandomDevice = fopen("/dev/urandom", "r");
          if(RandomDevice != NULL) {
-            if(fread(&number,sizeof(number),1,RandomDevice) == 1) {
+            if(fread(&number, sizeof(number), 1, RandomDevice) == 1) {
                srandom(number);
                RandomSource = RS_DEVICE;
                return(number);
@@ -107,12 +118,9 @@ uint32_t random32()
             fclose(RandomDevice);
          }
          RandomSource = RS_CLIB;
-         srandom((unsigned int)(getMicroTime() & (card64)0xffffffff));
-
-         LOG_WARNING
-         fputs("Unable to open /dev/urandom - using clib's random() function!\n",stdlog);
-         LOG_END
-       break;
+         srandom((unsigned int)(getMicroTime() & (uint64_t)0xffffffff));
+      break;
    }
    return(random());
+#endif
 }
