@@ -1,5 +1,5 @@
 /*
- *  $Id: tagitem.c,v 1.3 2002/08/22 09:37:26 dreibh Exp $
+ *  $Id: tagitem.c,v 1.1.1.1 2004/07/13 09:12:09 dreibh Exp $
  *
  * RSerPool implementation.
  *
@@ -11,14 +11,19 @@
  * Forschung (BMBF) of the Federal Republic of Germany (Frderkennzeichen 01AK045).
  * The authors alone are responsible for the contents.
  *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public
- * License as published by the Free Software Foundation; either
- * version 2.1 of the License, or (at your option) any later version.
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License
+ * as published by the Free Software Foundation; either version 2
+ * of the License, or (at your option) any later version.
  *
- * You should have received a copy of the GNU Lesser General Public
- * License along with this library; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
  *
  * There are two mailinglists available at http://www.sctp.de/rserpool.html
  * which should be used for any discussion related to this implementation.
@@ -32,6 +37,7 @@
 
 
 #include "tdtypes.h"
+#include "loglevel.h"
 #include "tagitem.h"
 
 
@@ -52,6 +58,81 @@ void tagListFree(struct TagItem* tagList)
 }
 
 
+/* ###### Count tag items ################################################ */
+size_t tagListGetSize(struct TagItem* tagList)
+{
+   size_t count = 0;
+   while(tagList[count].Tag != TAG_DONE) {
+      count++;
+   }
+   return(count + 1);
+}
+
+
+/* ###### Duplicate tag items ############################################ */
+struct TagItem* tagListDuplicate(struct TagItem* tagList)
+{
+   const size_t    count = tagListGetSize(tagList);
+   struct TagItem* copy  = tagListAllocate(count);
+   size_t          i;
+
+   if(copy) {
+      for(i = 0;i < count;i++) {
+         copy[i].Tag  = tagList[i].Tag;
+         copy[i].Data = tagList[i].Data;
+      }
+   }
+   return(copy);
+}
+
+
+/* ###### Duplicate tag items with filtering ############################# */
+struct TagItem* tagListDuplicateFilter(struct TagItem* tagList,
+                                       const tag_t*    filterArray)
+{
+   const size_t    count = tagListGetSize(tagList);
+   struct TagItem* copy  = tagListAllocate(count);
+   size_t          i, j, k=0;
+
+   if(copy) {
+      LOG_VERBOSE5
+      fputs("Filter-copying tag list...\n", stdlog);
+      LOG_END
+      for(i = 0, j = 0;i < count;i++) {
+         while(filterArray[k] != TAG_DONE) {
+            if(tagList[i].Tag == filterArray[k]) {
+               LOG_VERBOSE5
+               fprintf(stdlog,"Copying tag #%u\n", tagList[i].Tag);
+               LOG_END
+               copy[j].Tag  = tagList[i].Tag;
+               copy[j].Data = tagList[i].Data;
+               j++;
+               break;
+            }
+            k++;
+         }
+      }
+      copy[j++].Tag = TAG_DONE;
+      if(j < count) {
+         free((void*)&copy[j]);
+      }
+   }
+   return(copy);
+}
+
+
+/**
+  * Create a new tag item array containing all tag items of
+  * the given list which belong to any tag given in the filter
+  * array.
+  *
+  * @param tagList TagItem array.
+  * @return TagItem array or NULL in case of error.
+  */
+struct TagItem* tagListDuplicateFilter(struct TagItem* tagList,
+                                       const tag_t*    filterArray);
+
+
 /* ###### Get next tag item ############################################## */
 struct TagItem* tagListNext(struct TagItem* tagList)
 {
@@ -141,6 +222,26 @@ tagdata_t tagListGetData(struct TagItem* tagList,
 }
 
 
+/* ###### Set tag data ################################################### */
+struct TagItem* tagListSetData(struct TagItem* tagList,
+                               const tag_t     tag,
+                               const tagdata_t value)
+{
+   struct TagItem* found;
+
+   found = tagListFind(tagList,tag);
+   if(found != NULL) {
+      LOG_VERBOSE5
+      fprintf(stdlog,"Set value %u ($%x) for tag #%u\n",
+              (unsigned int)value, (unsigned int)value, tag);
+      LOG_END
+      found->Data = value;
+   }
+
+   return(found);
+}
+
+
 /* ###### Print tag items ################################################ */
 void tagListPrint(struct TagItem* tagList, FILE* fd)
 {
